#
# spec file for package qimgv
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qimgv
Version:        0.9.1
Release:        bp153.1.25
Summary:        Qt5 image viewer
License:        GPL-3.0-only
URL:            https://github.com/easymodo/qimgv
Source0:        https://github.com/easymodo/qimgv/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE qimgv-PIE.patch # aloisio@gmx.com add PIE flags
Patch1:         qimgv-PIE.patch
# PATCH-FIX-OPENSUSE qimgv-includepath.patch # aloisio@gmx.com use correct path for opencv includes
Patch2:         qimgv-includepath.patch
# PATCH-FIX-UPSTREAM qimgv-pluginpath_1.patch
Patch3:         qimgv-pluginpath_1.patch
# PATCH-FIX-UPSTREAM qimgv-pluginpath_2.patch
Patch4:         qimgv-pluginpath_2.patch
# PATCH-FIX-UPSTREAM qimgv-pluginpath_3.patch
Patch5:         qimgv-pluginpath_3.patch
BuildRequires:  cmake >= 3.13
%if 0%{?suse_version} > 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc8-c++
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  opencv-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.9
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(mpv) >= 1.22.0
Requires:       mpv >= 0.32.0

%description
Qt5 image viewer with webm support.

%prep
%autosetup -p1

%build
export CXX=g++
test -x "$(type -p g++-8)" && export CXX=g++-8
%cmake
%make_jobs

%install
%cmake_install

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_libdir}/%{name}
%{_libdir}/%{name}/player_mpv.so

%changelog
* Sun May 31 2020 Luigi Baldoni <aloisio@gmx.com>
- Drop qimgv-nosharedlib.patch
- Add qimgv-pluginpath_1.patch, qimgv-pluginpath_2.patch and
  qimgv-pluginpath_3.patch (fixes boo#1172315)
* Tue May  5 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.1
  * Fixed incorrect window position on launch (it occasionally
    shifted upwards by the height of titlebar)
  * Exif orientation not being applied (regression)
  * Expand images option not working correctly when expand limit
    is unset
  * Building with qt <5.14 now works again
- Drop qimgv-Qt512.patch (merged upstream)
* Fri May  1 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9
  What's new:
  * Directory tree & bookmarks in folder view
  * High quality scaling via OpenCV
  * Reduced memory usage when viewing zoomed images
  * Zoom level indicator
  * Image centering options
  * Slideshow mode (~ key)
  * Show directory now highlights current file
  * Improved touchpad support (see settings > controls)
  * gif playback controls. Play / pause & frame step, similar to
    video
  * Crop panel now has save button. Shortcut is Shift+Enter
  * Added an option to start into folder view
  * Support for HEIF / HEIC image format
  Bug fixes:
  * Window state is now saved correctly
  * Various UI fixes
  * Possible crash fix in thumbnailer
- Refreshed qimgv-nosharedlib.patch
- Dropped mpv-qthelper.patch (merged upstream)
- Added qimgv-includepath.patch and qimgv-Qt512.patch
* Thu Mar 19 2020 Luigi Baldoni <aloisio@gmx.com>
- Added mpv-qthelper.patch to fix build with new mpv
* Tue Feb 11 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.9
  What's new:
  * [FolderView] You can now edit / remove files right from
    folder view.
  * [FolderView] Scroll animations for keyboard navigation.
  * [Thumbnailer] Files are now stored as png. This fixes
    transparency in folder view.
  * [Panel] Scrollbar indicator.
  * [Viewer] Configurable zoom step.
  * [Viewer] Added another way to zoom: hold RMB and scroll.
  * [Viewer] Added expandLimit option.
  * Added jpeg save quality option.
  * Changed some default settings.
  * Updated theme & icons.
  Bug fixes:
  * Several bug fixes related to file operations.
  * Minor visual fixes.
  * Keyboard input fixes. All your keys should now work,
    including symbols accessible through shift.
  * Removed max zoom option.
  * [windows] Do not track subfolders.
  * [Thumbnailer] Fix for video files with %% in file path.
  * [FolderView] Thumbnails are now always uncropped.
  * [FolderView] Fixes for mouse scrolling.
  * Fix some keyboard focus issues.
  * File format detection fixes.
  * Crash fixes.
- Refreshed qimgv-nosharedlib.patch and qimgv-PIE.patch
- Removed group tag
* Tue Nov 12 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.8
  * Quick fix for the showDirectory feature
* Tue Nov 12 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.7
  What's new:
  * Added volume control actions: toggleMute, volumeUp,
    volumeDown
  * Added mute button
  * Added showDirectory action & context menu entry. Opens
    current dir in the default file manager.
  * Configurable text color for fullscreen info bar
  * Off-screen thumbnails are now unloaded to save memory
  Bug fixes:
  * Fixed file format detection issues
  * Fixed overlays sometimes losing keyboard focus
  * Fixed moving files (regression)
  * Fixed notification not being shown on file copy / move
  * Fixed some temporary files not being removed on windows
  * Fixed crash on indexed png with transparency
  * Fixed possible crash when renaming a file
  Other:
  * Images are now being saved through a temporary file in case
    something goes wrong
  * Fixed incorrect shortcuts for frameStep / frameStepBack
    (they were switched around)
* Tue Oct 15 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.6
  * Dramatically improved startup speed.
  * Added some missing hidpi icons
* Tue Oct  1 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.5
  * Crop: change behavior to match older versions
  * VideoControls: fix overlapping with panel
  * FolderView: scrollbar is now easier to hit while in fullscreen
  * Fix opening videos without correct mime type
* Sun Sep 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.4
  * fix rename window (regression)
  * show error when a file operation fails
* Thu Sep 19 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.3
  New stuff:
  * triggerScalingFilter action
  * Support drag'n'dropping out of qimgv
  Bug Fixes:
  * Save maximized window state
  * CMake fixes (VIDEO_SUPPORT option working incorrectly)
  * Some unicode fixes on windows
  * Fix lag during sorting mode switch
  * Fix icon grid behavior when a lot of files are being
    added/modified from outside
  * Fix clipboard file copying (via ctrl+c)
  * Load files with incorrect file extensions (when opened
    directly)
- Refreshed qimgv-nosharedlib.patch
- Added qimgv-PIE.patch
* Tue Aug 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.2
  * Fix new shortcuts not working when you update from 0.7.x
* Mon Aug 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.1
  New stuff:
  * qimgv will now track changes in the current directory. May
    not work for remote locations like smb shares.
  * You can now change sorting mode on-the-fly. It Just Werks.
  * Add sorting mode combobox in folder view, as well as
    shortcuts Shift + 1 / 2 / 3.
  * You can now rename files by pressing F2.
  * Added sxiv-like info bar at the bottom.
  * Added info panel that shows exif tags. Press I to toggle.
  * Copy current file to clipboard by pressing Ctrl+C.
  * Copy current file path by pressing Ctrl+Shift+C.
  * Force reload file F5.
  * Context menu now can be accessed by pressing Menu key.
  * You can now assign a different shortcut to context menu, it
    is no longer hardcoded to right click.
  * You can now assign a shortcut to toggle transparency grid
    display.
  * Improve folder view performance.
  * Improve touchpad scrolling when using libinput driver.
  * A more polished UI theme. I plan on implementing totally
    configurable theme via config files, but that is for another
    release.
  * Split config file in two parts. The main one will not change
    every time you open program.
  Bug fixes:
  * (important one) Fixed long startup times by moving
    videoplayer into a separate library that is loaded ondemand.
    I've seen some complaints about this, please give this
    version a try.
  * Fix some issues with mouse event handling.
  * Fix scaling working incorrectly for webp files.
  * Fix opening wrong directory when passed . as an argument.
  * Previously when you used "Open dialog" qimgv would sometimes
    hang. Now it doesn't do that.
  * Saving PNG files will no longed produce huge file sizes.
  Notes:
  * This release may be a bit buggy as it included quite a bit
    of refactoring. Stuff will get fixed promptly.
- Added qimgv-nosharedlib.patch
* Wed Jan 30 2019 aloisio@gmx.com
- Update to version 0.7.3
  * [FolderView] Zoom support
  * [FolderView] Ability to toggle filenames display
  * [FolderView] Icon grid is now centered
  * Re-done some of the icons, added HiDPI versions
  * Startup speed optimizations
  * Multiple UI related tweaks & bug fixes
  * Fixed build with Qt 5.9 (regression)
* Sat Jan 12 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.2
  * Improved HiDPI support
  * APNG support (via QtApng plugin - included in windows
    installer)
  * Optional RAW support via QtRaw plugin
  * Separate settings for fullscreen / windowed background
  * UI performance improvements
  * Updated some icons
  * Minor startup speed optimizations
  * Crop UI improvements
  * Smooth scroll checkbox now works again
  * Fixed some other bugs
  * Added --help text
* Tue Sep 18 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.1
  * Fix build with Qt 5.9
  * Fix build with musl libc
* Wed Aug  8 2018 aloisio@gmx.com
- Update to version 0.7.0
  New stuff:
  * Folder View mode. Toggle with Enter or Backspace. This mode
    will be further improved in future
  * Ability to run commands / shell scripts on a current image
    + Go to Settings/Scripts
    + Create a command
    + Add a shortcut just like for any regular action
  * Context menu
  * Video controls
  * Background transparency & blur support (KDE)
  * Directory sorting (name, date, file size)
  * Trash support
  Improvements:
  * A new icon
  * Redesigned settings window
  * Several ui improvements: auto-hiding top buttons,
    toggle-able info overlay etc
  * Updated theme
  * Exif rotation should now be auto-applied on image load
  * More responsive image switching (fixed a job management bug
    in Loader)
  * Configurable thread count for thumbnailer
  * Fixed some possible crashes
  Other:
  * Added build flags for some features (kde blur and video
    support)
- Dropped qimgv-0.6-qt511.patch (merged upstream)
* Mon Jun 11 2018 aloisio@gmx.com
- Update to version 0.6.3
  * You can now mirror images by pressing H / V keys.
  version 0.6.2
  * WebM/MP4 playback issues #49
  version 0.6.1
  * Initial HiDPI support. May be buggy.
  * Add scroll animation.
  * Add a checkbox for .mp4 playback.
  * Rewrite crop overlay logic.
  * Workaround for https://bugreports.qt.io/browse/QTBUG-66387
- Dropped qimgv-0.6-qt56.patch and
  qimgv-0.6-no_return_in_nonvoid.patch (merged upstream)
- Added qimgv-0.6-qt511.patch to fix build with Qt 5.11
* Fri Jan 12 2018 aloisio@gmx.com
- Initial package (v0.6)
